@@ -4,10 +4,11 @@ use warnings;
 use base qw( CatalystX::CRUD::YUI::Excel );
 use Carp;
 use Data::Dump qw( dump );
-use Class::C3;
 use Rose::DBx::Garden::Catalyst::TT;
+use MRO::Compat;
+use mro 'c3';
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 =head1 NAME
 
