@@ -6,8 +6,10 @@ use Data::Dump qw( dump );
 use base qw( Rose::DB::Object );
 use base qw( Rose::DB::Object::Helpers );
 use base qw( Rose::DBx::Object::MoreHelpers );
+use MRO::Compat;
+use mro 'c3';
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 =head1 NAME
 
