@@ -5,8 +5,10 @@ use base qw( CatalystX::CRUD::YUI::View );
 use Class::Inspector;
 use Path::Class;
 use Rose::DBx::Garden::Catalyst::TT;
+use MRO::Compat;
+use mro 'c3';
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 =head1 NAME
 
